/**
	This class provides a static function to compute the gcd
*/
public class BinaryEuclid{
	
	/**
		This function computes the greatest common denominator of two
		numbers using the binary Euclidean algorithm
		@param a first number
		@param b second number
		@return the gcd of a and b
		@see http://de.wikipedia.org/wiki/Euklidischer_Algorithmus
	*/
	public static int gcd(int a, int b){
		int m, n;
		//step 0: initialization
		m=a; n=b;
		
		//step 1: binarization
		int k=0;
		while((m%2) == 0 && (n%2) == 0){
			m/=2;
			n/=2;
			k++;
		}
		
		//step 5 ;-)
		while(m>0){ 
			//step 2: make m odd
			while( (m%2)==0 ) m/=2;
			//step 3: occasionally exchange m and n
			if(m<n){
				int tmp=n;
				n=m;
				m=tmp;
			}
		
			//step 4: reduce m
			m-=n;
		}
		
		//return the gcd
		return n * 1<<k; //1<<k == 2^k
		
	}
	
	
	public static void main(String[] args){
		System.out.println("ggT(128, 256) = " + BinaryEuclid.gcd(128,256));
	}
}